---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: Bezdarnost

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Install this '...'
2. Set up this train/inference '....'
3. Run this '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Ubuntu22]
 - Hardware [e.g. 2xRTX5090]
 - Version [e.g. python3.10, torch2.7.1, etc.]

**Additional context**
Add any other context about the problem here.
